Tutorials
=========

The best way to learn about GluonTS is to dive right in by following our tutorials. You can download each tutorial as a Jupyter notebook by clicking the *download* link at the top of each tutorial page.

Forecasting
-----------

.. container:: cards

   .. card::
      :title: Forecasting Tutorial
      :link: forecasting/tutorial.html


.. toctree::
   :hidden:
   :maxdepth: 1

   forecasting/tutorial.ipynb
